@@ -128,7 +128,7 @@ store_read_object.tar_aws <- function(store) {
   key <- store_aws_key(path)
   bucket <- store_aws_bucket(path)
   scratch <- path_scratch(
-    path_store = tempdir(),
+    path_store = path_scratch_dir_cloud(),
     pattern = basename(store_aws_key(path))
   )
   on.exit(unlink(scratch))
@@ -297,5 +297,5 @@ store_aws_hash <- function(key, bucket, region, endpoint, version, args) {
 
 #' @export
 store_get_packages.tar_aws <- function(store) {
-  c("paws", NextMethod())
+  c("paws.storage", NextMethod())
 }
