@@ -4,6 +4,8 @@ prelocal_new <- function(
   names = NULL,
   queue = NULL,
   reporter = NULL,
+  seconds_interval = NULL,
+  garbage_collection = NULL,
   envir = NULL,
   scheduler = NULL
 ) {
@@ -13,6 +15,8 @@ prelocal_new <- function(
     names = names,
     queue = queue,
     reporter = reporter,
+    seconds_interval = seconds_interval,
+    garbage_collection = garbage_collection,
     envir = envir,
     scheduler = scheduler
   )
@@ -30,6 +34,8 @@ prelocal_class <- R6::R6Class(
       names = NULL,
       queue = NULL,
       reporter = NULL,
+      seconds_interval = NULL,
+      garbage_collection = NULL,
       envir = NULL,
       scheduler = NULL
     ) {
@@ -38,8 +44,10 @@ prelocal_class <- R6::R6Class(
         meta = meta,
         names = names,
         queue = queue,
-        envir = envir,
-        reporter = reporter
+        reporter = reporter,
+        seconds_interval = seconds_interval,
+        garbage_collection = garbage_collection,
+        envir = envir
       )
       self$scheduler <- scheduler
     },
