@@ -86,12 +86,15 @@ tar_config_get_project <- function(name, yaml) {
     name,
     inherits = yaml$inherits,
     garbage_collection = yaml$garbage_collection %|||% FALSE,
+    label = yaml$label,
+    level_separation = yaml$level_separation,
     reporter_make = yaml$reporter_make %|||% "verbose",
     reporter_outdated = yaml$reporter_outdated %|||% "silent",
     script = yaml$script %|||% path_script_default(),
     seconds_interval = yaml$seconds_interval %|||% 0.5,
     shortcut = yaml$shortcut %|||% FALSE,
     store = yaml$store %|||% path_store_default(),
+    use_crew = yaml$use_crew %|||% TRUE,
     workers = yaml$workers %|||% 1L
   )
 }
@@ -101,12 +104,15 @@ tar_config_get_convert <- function(name, value) {
     name,
     inherits = if_any(is.null(value), NULL, as.character(value)),
     garbage_collection = as.logical(value),
+    label = if_any(is.null(value), NULL, as.character(value)),
+    level_separation = if_any(is.null(value), NULL, as.numeric(value)),
     reporter_make = as.character(value),
     reporter_outdated = as.character(value),
     script = as.character(value),
     seconds_interval = as.numeric(value),
     shortcut = as.logical(value),
     store = as.character(value),
+    use_crew = as.logical(value),
     workers = as.integer(max(1L, as.integer(value)))
   )
 }
