@@ -32,5 +32,5 @@ tar_definition <- function(
   default = targets::tar_target_raw("target_name", quote(identity()))
 ) {
   tar_assert_target(default)
-  if_any(tar_runtime$exists_target(), tar_runtime$get_target(), default)
+  if_any(!is.null(tar_runtime$target), tar_runtime$target, default)
 }
