@@ -16,6 +16,10 @@
 #' @inheritParams tar_make
 #' @param workers Positive integer, maximum number of transient
 #'   `future` workers allowed to run at any given time.
+#' @param garbage_collection Logical of length 1, whether to run garbage
+#'   collection on the main process before sending a target to a worker.
+#'   Independent from the `garbage_collection` argument of [tar_target()],
+#'   which controls garbage collection on the worker.
 #' @examples
 #' if (identical(Sys.getenv("TAR_EXAMPLES"), "true")) { # for CRAN
 #' tar_dir({ # tar_dir() runs code from a temp dir for CRAN.
@@ -33,12 +37,14 @@ tar_make_future <- function(
   names = NULL,
   shortcut = targets::tar_config_get("shortcut"),
   reporter = targets::tar_config_get("reporter_make"),
+  seconds_interval = targets::tar_config_get("seconds_interval"),
   workers = targets::tar_config_get("workers"),
   callr_function = callr::r,
   callr_arguments = targets::tar_callr_args_default(callr_function, reporter),
   envir = parent.frame(),
   script = targets::tar_config_get("script"),
-  store = targets::tar_config_get("store")
+  store = targets::tar_config_get("store"),
+  garbage_collection = targets::tar_config_get("garbage_collection")
 ) {
   force(envir)
   tar_assert_package("future")
@@ -50,11 +56,20 @@ tar_make_future <- function(
   tar_assert_ge(workers, 1)
   tar_assert_callr_function(callr_function)
   tar_assert_list(callr_arguments)
+  tar_assert_dbl(seconds_interval)
+  tar_assert_scalar(seconds_interval)
+  tar_assert_none_na(seconds_interval)
+  tar_assert_ge(seconds_interval, 0)
+  tar_assert_lgl(garbage_collection)
+  tar_assert_scalar(garbage_collection)
+  tar_assert_none_na(garbage_collection)
   targets_arguments <- list(
     path_store = store,
     names_quosure = rlang::enquo(names),
     shortcut = shortcut,
     reporter = reporter,
+    seconds_interval = seconds_interval,
+    garbage_collection = garbage_collection,
     workers = workers
   )
   out <- callr_outer(
@@ -76,6 +91,8 @@ tar_make_future_inner <- function(
   names_quosure,
   shortcut,
   reporter,
+  seconds_interval,
+  garbage_collection,
   workers
 ) {
   names <- tar_tidyselect_eval(names_quosure, pipeline_get_names(pipeline))
@@ -86,6 +103,8 @@ tar_make_future_inner <- function(
     shortcut = shortcut,
     queue = "parallel",
     reporter = reporter,
+    seconds_interval = seconds_interval,
+    garbage_collection = garbage_collection,
     workers = workers
   )$run()
   invisible()
