@@ -1,4 +1,5 @@
-# Use sparingly. We do not want to max out any AWS quotas.
+# Use sparingly to minimize AWS costs.
+# Verify all `targets` buckets are deleted afterwards.
 # After this test runs, log into the AWS console,
 # check that the prefix is correct, and MANUALLY CLEAR OUT THE BUCKET.
 # Run interactively to check the prefix.
@@ -6,7 +7,7 @@ tar_test("aws_parquet format returns data frames", {
   skip_if_no_aws()
   skip_if_not_installed("arrow")
   bucket_name <- random_bucket_name()
-  s3 <- paws::s3()
+  s3 <- paws.storage::s3()
   s3$create_bucket(Bucket = bucket_name)
   on.exit(aws_s3_delete_bucket(bucket_name))
   expr <- quote({
