@@ -66,6 +66,8 @@ tar_test("tar_path_target() returns non-cloud path for non-cloud storage", {
 })
 
 tar_test("tar_path_target() returns stage for cloud formats", {
+  skip_cran()
+  skip_on_os("windows")
   x <- tar_target(x, 1, format = "parquet", repository = "aws")
   store_update_stage_early(x$store, x$settings$name, path_store_default())
   dir <- dirname(x$store$file$stage)
@@ -77,7 +79,7 @@ tar_test("tar_path_target() returns stage for cloud formats", {
   expect_false(file.exists(dirname(out)))
   out <- tar_path_target(create_dir = TRUE)
   expect_true(file.exists(dirname(out)))
-  expect_equal(dirname(out), dirname(path_scratch(tempdir())))
+  expect_equal(dirname(out), file.path(path_scratch_dir_cloud(), "scratch"))
   expect_equal(out, x$store$file$stage)
 })
 
