@@ -3,7 +3,9 @@ tar_test("empty resources", {
 })
 
 tar_test("populated resources", {
-  skip_if_not_installed("paws")
+  skip_cran()
+  skip_on_os("windows")
+  skip_if_not_installed("paws.storage")
   out <- tar_resources(
     aws = resources_aws_init(),
     gcp = resources_gcp_init(),
@@ -19,7 +21,9 @@ tar_test("populated resources", {
 })
 
 tar_test("default resource args", {
-  skip_if_not_installed("paws")
+  skip_cran()
+  skip_on_os("windows")
+  skip_if_not_installed("paws.storage")
   tar_option_set(
     resources = tar_resources(
       aws = tar_resources_aws(bucket = "abc"),
@@ -38,7 +42,9 @@ tar_test("default resource args", {
 })
 
 tar_test("wrong resources", {
-  skip_if_not_installed("paws")
+  skip_cran()
+  skip_on_os("windows")
+  skip_if_not_installed("paws.storage")
   expect_error(
     tar_resources(aws = resources_qs_init()),
     class = "tar_condition_validate"
